@@ -14,6 +14,8 @@
 	 (riece-mcat "CTCP (Client To Client Protocol) support."))
    (cons 'riece-ctlseq
 	 (riece-mcat "Mark up control sequences in IRC buffers."))
+   (cons 'riece-desktop-notify
+	 (riece-mcat "Display notification to desktop."))
    (cons 'riece-doctor
 	 (riece-mcat "Pretend to be a psychotherapist."))
    (cons 'riece-epg
@@ -77,4 +79,4 @@
    (cons 'riece-yank
 	 (riece-mcat "Enter the element of kill-ring."))))
 
-(provide 'riece-addon-modules)
\ No newline at end of file
+(provide 'riece-addon-modules)
