@@ -1,4 +1,4 @@
-;;; riece-emacs.el --- FSF Emacs specific functions
+;;; riece-emacs.el --- FSF Emacs specific functions -*- lexical-binding: t -*-
 ;; Copyright (C) 1999 Daiki Ueno
 
 ;; Author: Daiki Ueno <ueno@unixuser.org>
@@ -19,8 +19,8 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Code:
 
@@ -48,7 +48,7 @@
 	     (car (last (symbol-function function)))
 	   function)))))
 
-(defun riece-popup-menu-popup (menu event)
+(defun riece-popup-menu-popup (menu _event)
   (let ((function (riece-popup-menu-bogus-filter-constructor menu)))
     (if function
 	(funcall function))))
@@ -135,6 +135,16 @@ If N is nil, all messages will be returned."
 	    (reverse-region (point-min) (point-max))
 	    (buffer-string))))))
 
+(defun riece-remprop (symbol property)
+  (let ((plist (symbol-plist symbol)))
+    (if (eq (car plist) property)
+	(setplist symbol (cdr (cdr plist)))
+      (while (and (nthcdr 2 plist)
+		  (not (eq (car (nthcdr 2 plist)) property)))
+	(setq plist (nthcdr 2 plist)))
+      (if (nthcdr 2 plist)
+	  (setcdr (cdr plist) (nthcdr 4 plist))))))
+
 (provide 'riece-emacs)
 
 ;;; riece-emacs.el ends here
