@@ -1,4 +1,4 @@
-;;; riece-guess.el --- guess the next channel, using multiple methods
+;;; riece-guess.el --- guess the next channel, using multiple methods -*- lexical-binding: t -*-
 ;; Copyright (C) 1998-2003 Daiki Ueno
 
 ;; Author: Daiki Ueno <ueno@unixuser.org>
@@ -18,8 +18,12 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
+
+;;; Commentary:
+
+;; NOTE: This is an add-on module for Riece.
 
 ;;; Code:
 
@@ -27,7 +31,7 @@
 (require 'riece-commands)
 
 (defgroup riece-guess nil
-  "Guess the next channel"
+  "Guess the next channel."
   :tag "Guess"
   :prefix "riece-"
   :group 'riece)
@@ -37,10 +41,8 @@
   :type '(repeat function)
   :group 'riece-guess)
 
-(defvar riece-guess-enabled nil)
-
 (defconst riece-guess-description
-  "Guess the next channel, using multiple methods")
+  "Guess the next channel, using multiple methods.")
 
 (defvar riece-current-channels)
 
@@ -99,8 +101,7 @@ merge the results."
   (define-key riece-dialogue-mode-map
     "g" 'riece-command-guess-switch-to-channel)
   (define-key riece-channel-list-mode-map
-    "g" 'riece-command-guess-switch-to-channel)
-  (setq riece-guess-enabled t))
+    "g" 'riece-command-guess-switch-to-channel))
 
 (defun riece-guess-disable ()
   (define-key riece-command-mode-map
@@ -108,8 +109,7 @@ merge the results."
   (define-key riece-dialogue-mode-map
     "g" nil)
   (define-key riece-channel-list-mode-map
-    "g" nil)
-  (setq riece-guess-enabled nil))
+    "g" nil))
 
 (provide 'riece-guess)
 
