@@ -1,7 +1,7 @@
-;;; riece-skk-kakutei.el --- add-on skk-kakutei
+;;; riece-skk-kakutei.el --- remove SKK's preedit mark before sending messages -*- lexical-binding: t -*-
 ;; Copyright (C) 2003 TAKAHASHI Kaoru
 
-;; Author: TAKAHASHI "beatmaria" Kaoru <kaoru@kaisei.org>
+;; Author: TAKAHASHI Kaoru <kaoru@kaisei.org>
 ;; Keywords: IRC, riece
 
 ;; This file is part of Riece.
@@ -18,24 +18,25 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Commentary:
 
-;; This add-on deny SKK's sankaku send.
-
-;; To use, add the following line to your ~/.riece/init.el:
-;; (add-to-list 'riece-addons 'riece-skk-kakutei)
+;; NOTE: This is an add-on module for Riece.
 
 ;;; Code:
 
 (eval-when-compile (require 'riece))
 
-(defvar riece-skk-kakutei-enabled nil)
+(defvar skk-mode)
+(defvar skk-henkan-mode)
+(defvar skk-henkan-on)
+(defvar skk-egg-like-newline)
+(autoload 'skk-kakutei "skk")
 
 (defconst riece-skk-kakutei-description
-  "Deny SKK's sankaku send")
+  "Remove SKK's preedit mark before sending messages.")
 
 (defun riece-skk-kakutei-command-enter-message ()
   "Send the current line to the current channel."
@@ -71,14 +72,12 @@
 (defun riece-skk-kakutei-enable ()
   (riece-define-keys riece-command-mode-map
     "\r" riece-skk-kakutei-command-enter-message
-    [(control return)] riece-skk-kakutei-command-enter-message-as-notice)
-  (setq riece-skk-kakutei-enabled t))
+    [(control return)] riece-skk-kakutei-command-enter-message-as-notice))
 
 (defun riece-skk-kakutei-disable ()
   (riece-define-keys riece-command-mode-map
     "\r" riece-command-enter-message
-    [(control return)] riece-command-enter-message-as-notice)
-  (setq riece-skk-kakutei-enabled nil))
+    [(control return)] riece-command-enter-message-as-notice))
 
 (provide 'riece-skk-kakutei)
 
