@@ -1,4 +1,4 @@
-;;; riece-unread.el --- mark channels where new messages arrived
+;;; riece-unread.el --- mark channels where new messages arrived -*- lexical-binding: t -*-
 ;; Copyright (C) 1998-2003 Daiki Ueno
 
 ;; Author: Daiki Ueno <ueno@unixuser.org>
@@ -18,8 +18,8 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Commentary:
 
@@ -84,7 +84,7 @@
 	  (setq riece-unread-channels (cons target riece-unread-channels))
 	  (riece-emit-signal 'channel-list-changed)))))
 
-(defun riece-unread-after-switch-to-channel-function (last)
+(defun riece-unread-after-switch-to-channel-function (_last)
   (if (get 'riece-unread 'riece-addon-enabled)
       (setq riece-unread-channels
 	    (delq (car (riece-identity-member riece-current-channel
@@ -128,6 +128,9 @@
   (let (requires)
     (if (memq 'riece-highlight riece-addons)
 	(setq requires (cons 'riece-highlight requires)))
+    ;; To override riece-history's channel mark in the channel list buffer.
+    (if (memq 'riece-history riece-addons)
+	(setq requires (cons 'riece-history requires)))
 ;;;    (if (memq 'riece-guess riece-addons)
 ;;;	(setq requires (cons 'riece-guess requires)))
     requires))
